@@ -10,14 +10,18 @@
 #include <QTextStream>
 #include <QUrl>
 
-#include <netinet/in.h>
-#include <sys/socket.h>
-#include <unistd.h>
-#ifndef Q_WS_WIN
-#include <netinet/in_systm.h>
-#include <netinet/ip.h>
-#endif
+#ifndef Q_OS_WIN
 #include <arpa/inet.h>
+#include <netinet/in_systm.h>
+#include <netinet/in.h>
+#include <netinet/ip.h>
+#include <sys/socket.h>
+#include <sys/types.h>
+#include <unistd.h>
+#else
+#include <Ws2tcpip.h>
+#endif
+
 #include <util/log.h>
 
 namespace bt
@@ -130,7 +134,11 @@ void UPnPMCastSocket::onReadyRead()
         // so we need to deal with it oursleves
         int fd = socketDescriptor();
         char tmp;
+#ifndef Q_OS_WIN
         ::read(fd, &tmp, 1);
+#else
+        recv(fd, &tmp, 1, 0);
+#endif
         return;
     }
 
@@ -170,7 +178,7 @@ void UPnPMCastSocket::saveRouters(const QString &file)
     // file format is simple : 2 lines per router,
     // one containing the server, the other the location
     QTextStream fout(&fptr);
-    for (UPnPRouter *r : std::as_const(d->routers)) {
+    for (const UPnPRouter *r : std::as_const(d->routers)) {
         fout << r->getServer() << Qt::endl;
         fout << r->getLocation().toString() << Qt::endl;
     }
@@ -235,10 +243,10 @@ void UPnPMCastSocket::UPnPMCastSocketPrivate::joinUPnPMCastGroup(int fd)
     struct ip_mreq mreq;
     memset(&mreq, 0, sizeof(struct ip_mreq));
 
-    inet_aton("239.255.255.250", &mreq.imr_multiaddr);
+    inet_pton(AF_INET, "239.255.255.250", &mreq.imr_multiaddr);
     mreq.imr_interface.s_addr = htonl(INADDR_ANY);
 
-#ifndef Q_WS_WIN
+#ifndef Q_OS_WIN
     if (setsockopt(fd, IPPROTO_IP, IP_ADD_MEMBERSHIP, &mreq, sizeof(struct ip_mreq)) < 0)
 #else
     if (setsockopt(fd, IPPROTO_IP, IP_ADD_MEMBERSHIP, (char *)&mreq, sizeof(struct ip_mreq)) < 0)
@@ -253,10 +261,10 @@ void UPnPMCastSocket::UPnPMCastSocketPrivate::leaveUPnPMCastGroup(int fd)
     struct ip_mreq mreq;
     memset(&mreq, 0, sizeof(struct ip_mreq));
 
-    inet_aton("239.255.255.250", &mreq.imr_multiaddr);
+    inet_pton(AF_INET, "239.255.255.250", &mreq.imr_multiaddr);
     mreq.imr_interface.s_addr = htonl(INADDR_ANY);
 
-#ifndef Q_WS_WIN
+#ifndef Q_OS_WIN
     if (setsockopt(fd, IPPROTO_IP, IP_DROP_MEMBERSHIP, &mreq, sizeof(struct ip_mreq)) < 0)
 #else
     if (setsockopt(fd, IPPROTO_IP, IP_DROP_MEMBERSHIP, (char *)&mreq, sizeof(struct ip_mreq)) < 0)
